@@ -8,7 +8,7 @@
 //! API, while trying to remain very close to it.
 //!
 //! It offers the choice of using it [*more like Rust*](#like-rust)
-//! and/or [*more like C*](#like-C).
+//! and/or [*more like C*](#like-c).
 //!
 //! ## Like Rust
 //!
@@ -16,7 +16,7 @@
 //! constructors, and error handling with the `NcResult` enum:
 //!
 //! ### Example
-#![doc = concat!["```\n", include_str!("../examples/hello-world-rust.rs"), "\n```" ]]
+#![doc = concat!["```ignore\n", include_str!("../examples/hello-world-rust.rs"), "\n```" ]]
 //!
 //! ### Notes on the Rust API
 //!
@@ -56,7 +56,7 @@
 //! or in case of receiving a pointer, by comparing it to `null_mut()`.
 //!
 //! ### Example
-#![doc = concat!["```\n", include_str!("../examples/hello-world-c.rs"), "\n```" ]]
+#![doc = concat!["```ignore\n", include_str!("../examples/hello-world-c.rs"), "\n```" ]]
 //!
 //! ### The `notcurses` C API docs
 //!
@@ -112,9 +112,9 @@ pub mod widgets;
 // Note that the names of the implemented traits can't coincide for type aliases
 // with the same underlying primitive, like in the case of `NcAlign` & `NcScale`
 // in which case are both aliases over `u32`.
-pub use align::{NcAlign, NcAlignApi};
-pub use alpha::{NcAlpha, NcAlphaApi};
-pub use blitter::{NcBlitter, NcBlitterApi};
+pub use align::NcAlign;
+pub use alpha::NcAlpha;
+pub use blitter::NcBlitter;
 pub use capabilities::NcCapabilities;
 pub use cell::NcCell;
 pub use channel::{NcChannel, NcChannelApi, NcChannels, NcChannelsApi, NcComponent, NcRgb};
@@ -134,7 +134,7 @@ pub use pixel::{NcPixel, NcPixelApi, NcPixelGeometry, NcPixelImpl, NcPixelImplAp
 pub use plane::{NcPlane, NcPlaneOptions, NcPlaneOptionsBuilder};
 pub use r#box::{NcBoxMask, NcBoxMaskApi};
 pub use resizecb::{NcResizeCb, NcResizeCbApi, NcResizeCbUnsafe};
-pub use scale::{NcScale, NcScaleApi};
+pub use scale::NcScale;
 pub use stats::NcStats;
 pub use string::NcString;
 pub use style::{NcStyle, NcStyleApi};
@@ -179,10 +179,10 @@ pub mod c_api {
     pub use crate::plane::reimplemented::*;
     pub use crate::resizecb::reimplemented::*;
 
-    // public re-export of reimplemented constants:
-    pub use crate::align::constants::*;
-    pub use crate::alpha::constants::*;
-    pub use crate::blitter::constants::*;
+    // public re-export of c_api constants & types:
+    pub use crate::align::c_api::*;
+    pub use crate::alpha::c_api::*;
+    pub use crate::blitter::c_api::*;
     pub use crate::channel::constants::*;
     pub use crate::direct::constants::*;
     pub use crate::error::constants::*;
@@ -195,7 +195,7 @@ pub mod c_api {
     pub use crate::pixel::constants::*;
     pub use crate::plane::options::constants::*;
     pub use crate::r#box::constants::*;
-    pub use crate::scale::constants::*;
+    pub use crate::scale::c_api::*;
     pub use crate::style::constants::*;
     pub use crate::visual::options::constants::*;
     pub use crate::widgets::menu::constants::*;
