@@ -4,10 +4,10 @@ use core::ptr::{null, null_mut};
 
 use crate::{
     c_api::{self, notcurses_init},
-    cstring, error, error_ref_mut, rstring, rstring_free, Nc, NcAlign, NcBlitter, NcBlitterApi,
-    NcCapabilities, NcChannels, NcDim, NcError, NcFile, NcInput, NcLogLevel, NcMiceEvents,
-    NcMiceEventsApi, NcOptions, NcPixelImpl, NcPlane, NcReceived, NcResult, NcScale, NcStats,
-    NcStyle, NcStyleApi, NcTime, NcVGeom, NcVisual, NcVisualGeometry, NcVisualOptions,
+    cstring, error, error_ref_mut, rstring, rstring_free, Nc, NcAlign, NcBlitter, NcCapabilities,
+    NcChannels, NcDim, NcError, NcFile, NcInput, NcLogLevel, NcMiceEvents, NcMiceEventsApi,
+    NcOptions, NcPixelImpl, NcPlane, NcReceived, NcResult, NcRgb, NcScale, NcStats, NcStyle,
+    NcStyleApi, NcTime, NcVGeom, NcVisual, NcVisualGeometry, NcVisualOptions,
 };
 
 /// # `NcOptions` Constructors
@@ -58,15 +58,7 @@ impl NcOptions {
         margin_l: NcDim,
         flags: u64,
     ) -> Self {
-        Self {
-            termtype: null(),
-            loglevel,
-            margin_t,
-            margin_r,
-            margin_b,
-            margin_l,
-            flags,
-        }
+        Self { termtype: null(), loglevel, margin_t, margin_r, margin_b, margin_l, flags }
     }
 }
 
@@ -172,15 +164,17 @@ impl Nc {
     /// Returns the offset into `availcols` at which `cols` ought be output given
     /// the requirements of `align`.
     ///
-    /// Returns `-`[`NcIntResult::MAX`][crate::NcIntResult::MAX] if
-    /// [NcAlign::UNALIGNED][NcAlign#associatedconstant.UNALIGNED]
-    /// or invalid [`NcAlign`].
+    /// Returns `-`[NcIntResult::MAX][crate::NcIntResult::MAX] if
+    /// [`NcAlign::Unaligned`].
     ///
     /// *C style function: [notcurses_align()][c_api::notcurses_align].*
-    //
-    // TODO: handle error rightfully.
-    pub fn align(availcols: NcDim, align: NcAlign, cols: NcDim) -> NcResult<()> {
-        error![c_api::notcurses_align(availcols, align, cols)]
+    pub fn align(availcols: NcDim, align: NcAlign, cols: NcDim) -> NcResult<NcDim> {
+        let res = c_api::notcurses_align(availcols, align, cols);
+        error![
+            res,
+            &format!("NcPlane.valign({:?}, {})", align, cols),
+            res as NcDim
+        ]
     }
 
     /// Retrieves the current contents of the specified [`NcCell`][crate::NcCell]
@@ -211,7 +205,7 @@ impl Nc {
 
     /// Returns true if we can reliably use Unicode Braille.
     ///
-    /// See also [`NcBlitter::BRAILLE`][NcBlitter#BRAILLE].
+    /// See also [`NcBlitter::Braille`].
     ///
     /// *C style function: [notcurses_canbraille()][c_api::notcurses_canbraille].*
     pub fn canbraille(&self) -> bool {
@@ -238,7 +232,7 @@ impl Nc {
 
     /// Returns true if we can reliably use Unicode half blocks.
     ///
-    /// See also [`Blitter::BLIT_2x1`][NcBlitter#associatedconstant.BLIT_2x1].
+    /// See also [`NcBlitter::Half`].
     ///
     /// *C style function: [notcurses_canhalfblock()][c_api::notcurses_canhalfblock].*
     pub fn canhalfblock(&self) -> bool {
@@ -274,7 +268,7 @@ impl Nc {
 
     /// Returns true if we can reliably use Unicode quadrant blocks.
     ///
-    /// See also [`NcBlitter::BLIT_2x2`][NcBlitter#associatedconstant.NCBLIT_2x2].
+    /// See also [`NcBlitter::Quadrant`].
     ///
     /// *C style function: [notcurses_canquadrant()][c_api::notcurses_canquadrant].*
     pub fn canquadrant(&self) -> bool {
@@ -283,7 +277,7 @@ impl Nc {
 
     /// Returns true if we can reliably use Unicode 13 sextants.
     ///
-    /// See also [`NcBlitter::BLIT_3x2`][NcBlitter#associatedconstant.NCBLIT_3x2].
+    /// See also [`NcBlitter::Sextant`].
     ///
     /// *C style function: [notcurses_cansextant()][c_api::notcurses_cansextant].*
     pub fn cansextant(&self) -> bool {
@@ -319,6 +313,28 @@ impl Nc {
         unsafe { c_api::notcurses_check_pixel_support(self) }
     }
 
+    /// Returns the default foreground color, if it is known.
+    pub fn default_forekground(&self) -> Option<NcRgb> {
+        let mut fg: NcRgb = 0;
+        let res = unsafe { c_api::notcurses_default_foreground(self, &mut fg) };
+        if res == c_api::NCRESULT_ERR {
+            None
+        } else {
+            Some(fg)
+        }
+    }
+
+    /// Returns the default background color, if it is known.
+    pub fn default_background(&self) -> Option<NcRgb> {
+        let mut bg: NcRgb = 0;
+        let res = unsafe { c_api::notcurses_default_background(self, &mut bg) };
+        if res == c_api::NCRESULT_ERR {
+            None
+        } else {
+            Some(bg)
+        }
+    }
+
     /// Disables the terminal's cursor, if supported.
     ///
     /// Immediate effect (no need for a call to notcurses_render()).
@@ -522,7 +538,8 @@ impl Nc {
         let mut blitter = 0;
         error![
             unsafe { c_api::notcurses_lex_blitter(cstring![blitter_str], &mut blitter) },
-            "Invalid blitter name", blitter
+            "Invalid blitter name",
+            blitter.into()
         ]
     }
 
@@ -539,11 +556,12 @@ impl Nc {
     /// Returns an [`NcScale`] from a string representation.
     ///
     /// *C style function: [notcurses_lex_scalemode()][c_api::notcurses_lex_scalemode].*
-    pub fn lex_scalemode(scalemode_str: &str) -> NcResult<NcScale> {
-        let mut scalemode = 0;
+    pub fn lex_scalemode(scale_str: &str) -> NcResult<NcScale> {
+        let mut scale = 0;
         error![
-            unsafe { c_api::notcurses_lex_scalemode(cstring![scalemode_str], &mut scalemode) },
-            "", scalemode
+            unsafe { c_api::notcurses_lex_scalemode(cstring![scale_str], &mut scale) },
+            "",
+            scale.into()
         ]
     }
 
@@ -756,14 +774,14 @@ impl Nc {
     ///
     /// *C style function: [notcurses_str_blitter()][c_api::notcurses_str_blitter].*
     pub fn str_blitter(blitter: NcBlitter) -> String {
-        rstring![c_api::notcurses_str_blitter(blitter)].to_string()
+        rstring![c_api::notcurses_str_blitter(blitter.into())].to_string()
     }
 
     /// Gets the name of an [`NcScale`] scaling mode.
     ///
     /// *C style function: [notcurses_str_scalemode()][c_api::notcurses_str_scalemode].*
-    pub fn str_scalemode(scalemode: NcScale) -> String {
-        rstring![c_api::notcurses_str_scalemode(scalemode)].to_string()
+    pub fn str_scalemode(scale: NcScale) -> String {
+        rstring![c_api::notcurses_str_scalemode(scale.into())].to_string()
     }
 
     /// Gets the lowercase name (or names) of the styles included in an [`NcStyle`].
@@ -849,7 +867,7 @@ impl Nc {
     /// If an [`NcVisualOptions`] is not provided, a default one will be used.
     ///
     /// Additionally `cdim_yx` and `maxpixel_yx` are only ever filled in if we
-    /// know them, and `maxpixel_yx` is only defined for `NcBlitter`::PIXEL.
+    /// know them, and `maxpixel_yx` is only defined for [`NcBlitter::Pixel`].
     ///
     /// # See also
     /// - [`NcVisual.geom`][NcVisual#method.geom]
@@ -898,7 +916,7 @@ impl Nc {
             scale_yx = Some((vg.scaley as NcDim, vg.scalex as NcDim));
 
             // pixel blitter only is defined for Ncblitter::PIXEL
-            if vg.blitter == NcBlitter::PIXEL {
+            if vg.blitter == NcBlitter::Pixel.into() {
                 maxpixel_yx = Some((vg.maxpixely as NcDim, vg.maxpixelx as NcDim));
             } else {
                 maxpixel_yx = None;
@@ -911,7 +929,7 @@ impl Nc {
             len_yx = None;
         } else {
             // `maxpixel_yx` only is defined for `Ncblitter`::PIXEL.
-            if vg.blitter == NcBlitter::PIXEL {
+            if vg.blitter == NcBlitter::Pixel.into() {
                 maxpixel_yx = Some((vg.maxpixely as NcDim, vg.maxpixelx as NcDim));
             } else {
                 maxpixel_yx = None;
@@ -963,14 +981,13 @@ impl Nc {
             maxpixel_yx,
             beg_yx,
             len_yx,
-
-            blitter: vg.blitter,
+            blitter: (vg.blitter as crate::c_api::NcBlitter_u32).into(),
         };
         Ok(vgeometry)
     }
 
     /// Like [`visual_geom`] but auto-fills the `NcVisualOptions` with
-    /// `NcBlitter::PIXEL` in order to get the maximum available resolution
+    /// `NcBlitter::Pixel` in order to get the maximum available resolution
     /// for `scale_yx`, which determines the minimum dot-size for an `NcVisual`.
     ///
     /// [`visual_geom`]: Nc#method.visual_geom
