@@ -1,4 +1,4 @@
-use crate::{Nc, NcDim, NcOffset, NcPlane, NcPlaneOptions};
+use crate::{c_api, Nc, NcDim, NcOffset, NcPlane, NcPlaneOptions};
 
 /// Helper function for a new NcPlane on C style tests.
 #[allow(dead_code)]
@@ -9,7 +9,7 @@ pub(crate) unsafe fn ncplane_new_test<'a>(
     rows: NcDim,
     cols: NcDim,
 ) -> &'a mut NcPlane {
-    &mut *crate::ncpile_create(nc, &NcPlaneOptions::new(y, x, rows, cols))
+    &mut *c_api::ncpile_create(nc, &NcPlaneOptions::new(y, x, rows, cols))
 }
 
 /// Helper function for a new bound NcPlane on C style tests.
@@ -21,5 +21,5 @@ pub(crate) unsafe fn ncplane_new_bound_test<'a>(
     rows: NcDim,
     cols: NcDim,
 ) -> &'a mut NcPlane {
-    &mut *crate::ncplane_create(plane, &NcPlaneOptions::new(y, x, rows, cols))
+    &mut *c_api::ncplane_create(plane, &NcPlaneOptions::new(y, x, rows, cols))
 }
